@@ -122,7 +122,7 @@ namespace LongoMatch.Gui
 			player.SetLogo(System.IO.Path.Combine(Config.ImagesDir(),"background.png"));
 			player.LogoMode = true;
 			player.Tick += OnTick;
-			player.Detach += (sender, e) => DetachPlayer(true);
+			player.Detach += DetachPlayer;
 
 			capturer.Visible = false;
 			capturer.Logo = System.IO.Path.Combine(Config.ImagesDir(),"background.png");
@@ -135,6 +135,8 @@ namespace LongoMatch.Gui
 			if (!Config.useGameUnits)
 				GameUnitsViewAction.Visible = false;
 			
+			MenuItem parent = ImportProjectActionMenu;
+			parent.Submenu = new Menu();
 			AddImportEntry(Catalog.GetString("Import file project"), "ImportFileProject",
 			               Constants.PROJECT_NAME + " (" + Constants.PROJECT_EXT + ")",
 			               "*" + Constants.PROJECT_EXT, Project.Import,
@@ -221,8 +223,7 @@ namespace LongoMatch.Gui
 		public void AddImportEntry (string name, string shortName, string filterName,
 		                            string filter, Func<string, Project> importFunc,
 		                            bool requiresNewFile) {
-			MenuItem parent = (MenuItem) this.UIManager.GetWidget("/menubar1/FileAction/ImportProjectAction");
-			
+			MenuItem parent = ImportProjectActionMenu;
 			MenuItem item = new MenuItem(name);
 			item.Activated += (sender, e) => (EmitImportProject(name, filterName, filter, importFunc, requiresNewFile));
 			item.Show();
@@ -232,6 +233,12 @@ namespace LongoMatch.Gui
 		
 		#region Private Methods
 		
+		MenuItem ImportProjectActionMenu {
+			get {
+				return (MenuItem) this.UIManager.GetWidget("/menubar1/FileAction/ImportProjectAction");
+			}
+		}
+		
 		private void ConnectSignals() {
 			/* Adding Handlers for each event */
 
@@ -341,6 +348,7 @@ namespace LongoMatch.Gui
 					action = TaggingViewAction;
 				OnViewToggled(action, new EventArgs());
 			}
+			player.Detached = detach;
 		}
 
 		public void SetProject(Project project, ProjectType projectType, CaptureSettings props, PlaysFilter filter)
